/*
vert file and comments from adam ferriss
https://github.com/aferriss/p5jsShaderExamples
with additional comments from Louise Lessel
*/


// These are necessary definitions that let you graphics card know how to render the shader
#ifdef GL_ES
precision mediump float;
#endif


// This “vec3 aPosition” is a built in shader functionality. You must keep that naming.
// It automatically gets the position of every vertex on your canvas

attribute vec3 aPosition;
attribute vec4 aVertexColor;
attribute vec3 aNormal;
attribute vec2 aTexCoord;

varying vec3 var_vertPos;
varying vec4 var_vertCol;
varying vec3 var_vertNormal;
varying vec2 var_vertTexCoord;

uniform mat4 uModelViewMatrix;
uniform mat4 uProjectionMatrix;
uniform mat3 uNormalMatrix;

// We always must do at least one thing in the vertex shader:
// tell the pixel where on the screen it lives:

void main() {
	// copy the position data into a vec4, using 1.0 as the w component
	vec4 positionVec4 = vec4(aPosition, 1.0);

	// Make sure the shader covers the entire screen:
	// scale the rect by two, and move it to the center of the screen
	// if we don't do this, it will appear with its bottom left corner in the center of the sketch
	// try commenting this line out to see what happens
	positionVec4.xy = positionVec4.xy * 2.0 - 1.0;

	// Send the vertex information on to the fragment shader
	// this is done automatically, as long as you put it into the built in shader function “gl_Position”
	gl_Position = positionVec4;
	var_vertPos = aPosition;
	var_vertCol = aVertexColor;
	var_vertNormal = aNormal;
	var_vertTexCoord = aTexCoord;
}
